'use strict';
const ManagerController = require('../manager.js');
/**
 * [exports 产品分类]
 * @type {[type]}
 */
module.exports = class ProductCategoryController extends ManagerController {
    /**
     * [useModel 使用模型]
     * @return {[type]} [description]
     */
    get useModel() {
        let that = this;
        return that.app.model.ProductCategory;
    }
    /**
     * [createValidate 添加产品分类验证器]
     * @return {[type]} [description]
     */
    get createValidate() {
        let that = this;
        return {
            category_name:that.ctx.rules.name('分类名称').required().notEmpty().trim(),
            pid:that.ctx.rules.default(0).required().number(),
            category_image:that.ctx.rules.default('').required(),
            category_sort:that.ctx.rules.default(99).number().extend((field,value,row) => {
                if(!value) row[field] = 99;
            }),
            is_show:that.ctx.rules.default(1).number(),
            is_nav:that.ctx.rules.default(0).number(),
            category_attrs:that.ctx.rules.default('').required().extend(async (field,value,row) => {
                if(value) row[field] = await that.ctx.postParse(field,'',val => val);
            }),
            admin_id:that.ctx.rules.default(that.service.manager.ActionAdminUserId()).number(),
            create_time:that.ctx.rules.default(that.app.szjcomo.date('Y-m-d H:i:s')).required()
        };
    }
    /**
     * [deleteValidate 删除分类]
     * @return {[type]} [description]
     */
    get deleteValidate() {
        let that = this;
        return {
            category_id:that.ctx.rules.name('分类ID').required().notEmpty().number().extend(async (field,value,row) => {
                let childCount = await that.useModel.findOne({where:{pid:value},attributes:['category_id']});
                if(childCount) return '当前分类下还有子分类,无法删除';
                let productsCount = await that.app.model.Products.findOne({where:{category_id:value},attributes:['product_id']});
                if(productsCount) return '当前分类下还有商品,无法删除';
            })
        };
    }
    /**
     * [selectValidate 获取商品分类列表]
     * @return {[type]} [description]
     */
    get selectValidate() {
        let that = this;
        return {
            page:that.ctx.rules.default(1).number(),
            limit:that.ctx.rules.default(500).number()
        };
    }
    /**
     * [updateValidate 更新商品分类验证器]
     * @return {[type]} [description]
     */
    get updateValidate() {
        let that = this;
        return {
            category_id:that.ctx.rules.name('分类ID').required().notEmpty().number(),
            admin_id:that.ctx.rules.default(that.service.manager.ActionAdminUserId()).number(),
            update_time:that.ctx.rules.default(that.app.szjcomo.date('Y-m-d H:i:s')).required().extend(async (field,value,row) => {
                if(row.category_attrs) {
                    row.category_attrs = await that.ctx.anyParse('category_attrs','',val => val);
                }
            })
        };
    }
    /**
     * [selectOptions 查询参数]
     * @param  {Object} data [description]
     * @return {[type]}      [description]
     */
    async selectOptions(data = {}) {
        let that = this;
        let options = {offset:(data.page - 1)*data.limit,limit:data.limit,include:[
            {model:that.app.model.AdminUser,as:'admin_user',attributes:[]}
        ],attributes:{
            exclude:['admin_id'],
            include:[[that.app.Sequelize.col('admin_user.username'),'username']]
        },order:[['category_id','desc']]};
        return options;
    }
    
}